==> ogre-next-debug-2.3.3-2-x86_64.pkg.tar.zst: usr/src/debug/ogre-next/ogre-next-2.3.3/Samples/2.0/ApiUsage/UpdatingDecalsAndAreaLightTex/UpdatingDecalsAndAreaLightTexGameState.h <==

#ifndef _Demo_UpdatingDecalsAndAreaLightTexGameState_H_
#define _Demo_UpdatingDecalsAndAreaLightTexGameState_H_

#include "OgrePrerequisites.h"
#include "OgreOverlayPrerequisites.h"
#include "OgreOverlay.h"
#include "TutorialGameState.h"


namespace Demo
{
    static const Ogre::uint32 c_numAreaLights = 4u;

    class UpdatingDecalsAndAreaLightTexGameState : public TutorialGameState
    {
        Ogre::SceneNode     *mLightNodes[c_numAreaLights];
        Ogre::Light         *mAreaLights[c_numAreaLights];

        bool                mUseTextureFromFile[c_numAreaLights];
        float               mLightTexRadius[c_numAreaLights];

        Ogre::TextureGpu    *mAreaMaskTex;
        bool                mUseSynchronousMethod;

        /** Creates an Image of a hollow rectangle on the GPU
        @param radius
            Radius of the hollow rectangle (i.e. width of the "lines")
        @param outImage
            Image containing the texture to upload to GPU
        */
        void createAreaMask( float radius, Ogre::Image2 &outImage );
        /// Creates the Mesh for the billboards
        void createAreaPlaneMesh(void);
        /// Setups a datablock (material) for the billboard showing where the light is
        /// emitting so that it can use the same texture the light is using.
        ///
        /// Must be called again whenever the texture changes (i.e. setupLightTexture was called)
        Ogre::HlmsDatablock* setupDatablockTextureForLight( Ogre::Light *light, size_t idx );
        /// Creates a billboard showing where the given light is emitting
        void createPlaneForAreaLight( Ogre::Light *light, size_t idx );

        void createLight( const Ogre::Vector3 &position, size_t idx );
        /// Calls createAreaMask and uploads it to the GPU texture.
        void setupLightTexture( size_t idx );

        virtual void generateDebugText( float timeSinceLast, Ogre::String &outText );

    public:
        UpdatingDecalsAndAreaLightTexGameState( const Ogre::String &helpDescription );

        virtual void createScene01(void);
        virtual void destroyScene(void);

        virtual void update( float timeSinceLast );

        virtual void keyReleased( const SDL_KeyboardEvent &arg );
    };
}

#endif

==> ogre-next-debug-3.0.0-1-x86_64.pkg.tar.zst: usr/src/debug/ogre-next/ogre-next-3.0.0/Samples/2.0/ApiUsage/UpdatingDecalsAndAreaLightTex/UpdatingDecalsAndAreaLightTexGameState.h <==

#ifndef _Demo_UpdatingDecalsAndAreaLightTexGameState_H_
#define _Demo_UpdatingDecalsAndAreaLightTexGameState_H_

#include "OgreOverlay.h"
#include "OgreOverlayPrerequisites.h"
#include "OgrePrerequisites.h"

#include "TutorialGameState.h"

namespace Demo
{
    static const Ogre::uint32 c_numAreaLights = 4u;

    class UpdatingDecalsAndAreaLightTexGameState : public TutorialGameState
    {
        Ogre::SceneNode *mLightNodes[c_numAreaLights];
        Ogre::Light *mAreaLights[c_numAreaLights];

        bool mUseTextureFromFile[c_numAreaLights];
        float mLightTexRadius[c_numAreaLights];

        Ogre::TextureGpu *mAreaMaskTex;
        bool mUseSynchronousMethod;

        /** Creates an Image of a hollow rectangle on the GPU
        @param radius
            Radius of the hollow rectangle (i.e. width of the "lines")
        @param outImage
            Image containing the texture to upload to GPU
        */
        void createAreaMask( float radius, Ogre::Image2 &outImage );
        /// Creates the Mesh for the billboards
        void createAreaPlaneMesh();
        /// Setups a datablock (material) for the billboard showing where the light is
        /// emitting so that it can use the same texture the light is using.
        ///
        /// Must be called again whenever the texture changes (i.e. setupLightTexture was called)
        Ogre::HlmsDatablock *setupDatablockTextureForLight( Ogre::Light *light, size_t idx );
        /// Creates a billboard showing where the given light is emitting
        void createPlaneForAreaLight( Ogre::Light *light, size_t idx );

        void createLight( const Ogre::Vector3 &position, size_t idx );
        /// Calls createAreaMask and uploads it to the GPU texture.
        void setupLightTexture( size_t idx );

        void generateDebugText( float timeSinceLast, Ogre::String &outText ) override;

    public:
        UpdatingDecalsAndAreaLightTexGameState( const Ogre::String &helpDescription );

        void createScene01() override;
        void destroyScene() override;

        void update( float timeSinceLast ) override;

        void keyReleased( const SDL_KeyboardEvent &arg ) override;
    };
}  // namespace Demo

#endif
